Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(492)

Unified Diff: ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c

Issue 564573002: PPAPI: Make PPP_MessageHandler work in PNaCl (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Merge Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/generators/idl_c_proto.py ('k') | ppapi/proxy/interface_list.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
diff --git a/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c b/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
index 12d73b5e4560dbf7bdfa6cf5bc5c052cc7af6379..ee1219b0a495108c90d890cb3a7537ca89cc30bf 100644
--- a/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
+++ b/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
@@ -124,7 +124,7 @@ static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_MediaStreamVideoTrack_0_1
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_MediaStreamVideoTrack_1_0;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_MessageLoop_1_0;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Messaging_1_0;
-static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Messaging_1_1;
+static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Messaging_1_2;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_MouseLock_1_0;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_NetAddress_1_0;
static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_NetworkList_1_0;
@@ -1329,24 +1329,24 @@ static void Pnacl_M14_PPB_Messaging_PostMessage(PP_Instance instance, struct PP_
/* End wrapper methods for PPB_Messaging_1_0 */
-/* Begin wrapper methods for PPB_Messaging_1_1 */
+/* Begin wrapper methods for PPB_Messaging_1_2 */
-static void Pnacl_M37_PPB_Messaging_PostMessage(PP_Instance instance, struct PP_Var* message) {
- const struct PPB_Messaging_1_1 *iface = Pnacl_WrapperInfo_PPB_Messaging_1_1.real_iface;
+static void Pnacl_M39_PPB_Messaging_PostMessage(PP_Instance instance, struct PP_Var* message) {
+ const struct PPB_Messaging_1_2 *iface = Pnacl_WrapperInfo_PPB_Messaging_1_2.real_iface;
iface->PostMessage(instance, *message);
}
-static int32_t Pnacl_M37_PPB_Messaging_RegisterMessageHandler(PP_Instance instance, void* user_data, const struct PPP_MessageHandler_0_1* handler, PP_Resource message_loop) {
- const struct PPB_Messaging_1_1 *iface = Pnacl_WrapperInfo_PPB_Messaging_1_1.real_iface;
+static int32_t Pnacl_M39_PPB_Messaging_RegisterMessageHandler(PP_Instance instance, void* user_data, const struct PPP_MessageHandler_0_2* handler, PP_Resource message_loop) {
+ const struct PPB_Messaging_1_2 *iface = Pnacl_WrapperInfo_PPB_Messaging_1_2.real_iface;
return iface->RegisterMessageHandler(instance, user_data, handler, message_loop);
}
-static void Pnacl_M37_PPB_Messaging_UnregisterMessageHandler(PP_Instance instance) {
- const struct PPB_Messaging_1_1 *iface = Pnacl_WrapperInfo_PPB_Messaging_1_1.real_iface;
+static void Pnacl_M39_PPB_Messaging_UnregisterMessageHandler(PP_Instance instance) {
+ const struct PPB_Messaging_1_2 *iface = Pnacl_WrapperInfo_PPB_Messaging_1_2.real_iface;
iface->UnregisterMessageHandler(instance);
}
/* End wrapper methods for PPB_Messaging_1_1 */
/* Not generating wrapper methods for PPB_MouseCursor_1_0 */
@@ -2121,7 +2121,7 @@ static void Pnacl_M18_PPB_WebSocket_GetURL(struct PP_Var* _struct_result, PP_Res
/* Not generating wrapper methods for PPP_Instance_1_1 */
/* Not generating wrapper methods for PPP_MessageHandler_0_1 */
/* Begin wrapper methods for PPP_Messaging_1_0 */
@@ -4819,10 +4819,10 @@ static const struct PPB_Messaging_1_0 Pnacl_Wrappers_PPB_Messaging_1_0 = {
.PostMessage = (void (*)(PP_Instance instance, struct PP_Var message))&Pnacl_M14_PPB_Messaging_PostMessage
};
-static const struct PPB_Messaging_1_1 Pnacl_Wrappers_PPB_Messaging_1_1 = {
- .PostMessage = (void (*)(PP_Instance instance, struct PP_Var message))&Pnacl_M37_PPB_Messaging_PostMessage,
- .RegisterMessageHandler = (int32_t (*)(PP_Instance instance, void* user_data, const struct PPP_MessageHandler_0_1* handler, PP_Resource message_loop))&Pnacl_M37_PPB_Messaging_RegisterMessageHandler,
- .UnregisterMessageHandler = (void (*)(PP_Instance instance))&Pnacl_M37_PPB_Messaging_UnregisterMessageHandler
+static const struct PPB_Messaging_1_2 Pnacl_Wrappers_PPB_Messaging_1_2 = {
+ .PostMessage = (void (*)(PP_Instance instance, struct PP_Var message))&Pnacl_M39_PPB_Messaging_PostMessage,
+ .RegisterMessageHandler = (int32_t (*)(PP_Instance instance, void* user_data, const struct PPP_MessageHandler_0_2* handler, PP_Resource message_loop))&Pnacl_M39_PPB_Messaging_RegisterMessageHandler,
+ .UnregisterMessageHandler = (void (*)(PP_Instance instance))&Pnacl_M39_PPB_Messaging_UnregisterMessageHandler
};
/* Not generating wrapper interface for PPB_MouseCursor_1_0 */
@@ -5053,7 +5053,7 @@ static const struct PPB_WebSocket_1_0 Pnacl_Wrappers_PPB_WebSocket_1_0 = {
/* Not generating wrapper interface for PPP_Instance_1_1 */
/* Not generating wrapper interface for PPP_MessageHandler_0_1 */
static const struct PPP_Messaging_1_0 Pnacl_Wrappers_PPP_Messaging_1_0 = {
.HandleMessage = &Pnacl_M14_PPP_Messaging_HandleMessage
@@ -5896,9 +5896,9 @@ static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Messaging_1_0 = {
.real_iface = NULL
};
-static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Messaging_1_1 = {
- .iface_macro = PPB_MESSAGING_INTERFACE_1_1,
- .wrapped_iface = (const void *) &Pnacl_Wrappers_PPB_Messaging_1_1,
+static struct __PnaclWrapperInfo Pnacl_WrapperInfo_PPB_Messaging_1_2 = {
+ .iface_macro = PPB_MESSAGING_INTERFACE_1_2,
+ .wrapped_iface = (const void *) &Pnacl_Wrappers_PPB_Messaging_1_2,
.real_iface = NULL
};
@@ -6411,7 +6411,7 @@ static struct __PnaclWrapperInfo *s_ppb_wrappers[] = {
&Pnacl_WrapperInfo_PPB_MediaStreamVideoTrack_1_0,
&Pnacl_WrapperInfo_PPB_MessageLoop_1_0,
&Pnacl_WrapperInfo_PPB_Messaging_1_0,
- &Pnacl_WrapperInfo_PPB_Messaging_1_1,
+ &Pnacl_WrapperInfo_PPB_Messaging_1_2,
&Pnacl_WrapperInfo_PPB_MouseLock_1_0,
&Pnacl_WrapperInfo_PPB_NetAddress_1_0,
&Pnacl_WrapperInfo_PPB_NetworkList_1_0,
@@ -1329,24 +1329,24 @@ static void Pnacl_M14_PPB_Messaging_PostMessage(PP_Instance instance, struct PP_
iface->UnregisterMessageHandler(instance);
}
-/* End wrapper methods for PPB_Messaging_1_1 */
+/* End wrapper methods for PPB_Messaging_1_2 */
/* Not generating wrapper methods for PPB_MouseCursor_1_0 */
@@ -2121,7 +2121,7 @@ static void Pnacl_M18_PPB_WebSocket_GetURL(struct PP_Var* _struct_result, PP_Res
/* Not generating wrapper methods for PPP_Instance_1_1 */
-/* Not generating wrapper methods for PPP_MessageHandler_0_1 */
+/* Not generating wrapper methods for PPP_MessageHandler_0_2 */
/* Begin wrapper methods for PPP_Messaging_1_0 */
@@ -5053,7 +5053,7 @@ static const struct PPB_WebSocket_1_0 Pnacl_Wrappers_PPB_WebSocket_1_0 = {
/* Not generating wrapper interface for PPP_Instance_1_1 */
-/* Not generating wrapper interface for PPP_MessageHandler_0_1 */
+/* Not generating wrapper interface for PPP_MessageHandler_0_2 */
static const struct PPP_Messaging_1_0 Pnacl_Wrappers_PPP_Messaging_1_0 = {
.HandleMessage = &Pnacl_M14_PPP_Messaging_HandleMessage
« no previous file with comments | « ppapi/generators/idl_c_proto.py ('k') | ppapi/proxy/interface_list.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698